import { EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { report } from '../components/case-type-slider/case-type.component';
import { ReportACaseService } from '../services/report-a-case.service';
import { UiKitService } from '../../workflow-services/ui-kit.service';
import { OrganizationUserService } from '../../workflow-services/organization-user.service';
import { ResponsibilityService } from '../../workflow-services/responsibility.service';
import { ComplianceCommonService } from '../../workflow-services/common-workflow-services/compliance-common.service';
import { IframeService } from '../../services/iframe.service';
import * as i0 from "@angular/core";
export declare class WorkflowCaseComponent implements OnInit, OnDestroy {
    private reportACaseService;
    private uiKitService;
    private organizationUserService;
    private responsibilityService;
    private complianceCommonService;
    private iframeService;
    reportTexts: {
        case_type: string;
        report_case: string;
        add_case: string;
        default_flow: string;
        receive_updates: string;
        case_details: {
            name: {
                title: string;
                placeholder: string;
            };
            description: {
                title: string;
                placeholder: string;
            };
            rc: {
                title: string;
                placeholder: string;
                singularText: string;
                pluralText: string;
                mainRcPlaceholder: string;
                separateRcText: string;
                separateRcTooltip: string;
                sameRcText: string;
                sameRcTooltip: string;
            };
            case_type: {
                title: string;
                placeholder: string;
            };
            category: {
                title: string;
                placeholder: string;
            };
            additional_category: {
                title: string;
                placeholder: string;
            };
            when: {
                title: string;
                placeholder: string;
            };
            priority: {
                title: string;
                placeholder: string;
            };
            attachments: {
                title: string;
                placeholder: string;
            };
            due_date: {
                title: string;
                placeholder: string;
                deadline_placeholder: string;
                disabledText: string;
                helpText: string;
            };
            assignees: {
                title: string;
                placeholder: string;
                helpText: string;
            };
            owners: {
                title: string;
                placeholder: string;
                helpText: string;
                disabledText: string;
            };
        };
        tooltipMessage: {
            report_case: string;
            add_case: string;
            receive_updates: string;
            rc: string;
            workflow: string;
        };
        errorMessage: {
            rc: string;
            name: string;
            description: string;
            caseType: string;
            reportDate: string;
            priority: string;
            mainRc: string;
            caseOwner: string;
            caseAssignee: string;
            dueDate: string;
            stageAssignee: string;
            caseResolutionDeadline: string;
        };
    };
    ASSETS: {
        responsibility_center: string;
        case_type: string;
        case_category: string;
        when: string;
        what: string;
        case_resolution_deadline: string;
        case_assignees: string;
        format_evidence: string;
        case_owners: string;
        link_controls: string;
        link_items: string;
        spreadsheet_multiple_category: string;
        recommended_action: string;
        risks: string;
        exception_type: string;
        priority: string;
        associated_risks: string;
        oversight: string;
        add_risk_more_option: string;
        lables: string;
        reviewer: string;
        checkpoints: string;
        assessments: string;
        objectives: string;
        audit: string;
        roles: string;
        approval: string;
        recurring: string;
        lock_scope: string;
        custom_fields: string;
        link_risks: string;
        placeholder: string;
        add_logic: string;
        image_choice: string;
        logic_image_choice: string;
        thank_you_image: string;
        upload: string;
        select_users: string;
        everyone_as_per_category: string;
        bulb: string;
        enter_icon: string;
        im_creating: string;
        notes: string;
        attestations: string;
        risk_category: string;
        issue_type: string;
        type: string;
        search_data: string;
        approval_workflow: string;
        sequential: string;
        round_robin: string;
        anyone: string;
        collaborator: string;
    };
    caseType: typeof report;
    caseTypeSelected: report;
    payload: any;
    params: {
        rc_details: {
            id: string;
        };
        case_type: {
            id: string;
        };
        priority: {
            id: string;
        };
        category: {
            id: string;
        };
    };
    validationError: {
        name: {
            isError: boolean;
            message: string;
        };
        description: {
            isError: boolean;
            message: string;
        };
        reportDate: {
            isError: boolean;
            message: string;
        };
        caseType: {
            isError: boolean;
            message: string;
        };
        priority: {
            isError: boolean;
            message: string;
        };
        rc: {
            isError: boolean;
            message: string;
        };
        mainRc: {
            isError: boolean;
            message: string;
        };
        caseOwner: {
            isError: boolean;
            message: string;
        };
        caseAssignee: {
            isError: boolean;
            message: string;
        };
        caseResolutionDeadline: {
            isError: boolean;
            message: string;
        };
    };
    riskClassification: {
        name: string;
        value: number;
        class: string;
    }[];
    addToCasePayload: any;
    exceptionType: {
        DESIGN_EXCEPTION: string;
        EFFECTIVENESS_EXCEPTION: string;
    };
    oversight_config: {
        panelTitle: string;
        floatingTextSingular: string;
        searchPlaceholder: string;
        searchEnabled: boolean;
        selectAllEnabled: boolean;
        noDataText: string;
    };
    smileyMessage: string;
    actionButtons: any[];
    sideSelectorElements: any;
    additionalOptionStatus: any;
    fieldSelector: string[];
    caseData: any;
    fieldClicked: string;
    activeField: string;
    activeSelector: string;
    showSmiley: boolean;
    scrollToBottom: boolean;
    workflowDetailsData: any;
    groupList: any[];
    userList: any;
    selectedOversights: any;
    loader: {
        userListLoader: boolean;
        typeLoader: boolean;
        priorityLoader: boolean;
        caseLoader: boolean;
        groupListLoader: boolean;
        reportCaseLoader: boolean;
        permissionLoader: boolean;
    };
    openedFrom: any;
    source: any;
    caseId: any;
    mode: any;
    workflowType: any;
    responsibilityData: any;
    assessmentQuestion: any;
    caseTypePermission: boolean;
    closeWorkflow: EventEmitter<any>;
    populateOption: EventEmitter<any>;
    caseReportedBy: EventEmitter<any>;
    userListEmitter: EventEmitter<any>;
    disconnectRefresh: EventEmitter<any>;
    pickerChanged: EventEmitter<any>;
    constructor(reportACaseService: ReportACaseService, uiKitService: UiKitService, organizationUserService: OrganizationUserService, responsibilityService: ResponsibilityService, complianceCommonService: ComplianceCommonService, iframeService: IframeService);
    ngOnDestroy(): void;
    ngOnInit(): void;
    permissionLoader(): void;
    getUserList(): void;
    getGroupList(): void;
    getCaseDetails(): void;
    setCaseDetails(res: any): void;
    getWorkflowDetails(data: any): void;
    populateReportCasePayload(data: any): void;
    populateAddCasePayload(data: any): void;
    populateUserDetails(data: any): void;
    populateResolutionDeadline(data: any): void;
    populateAdditionalFields(data: any): void;
    populateOversights(): void;
    setOptionalField(data: any, riskClass: number): void;
    populateOptionalFields(): void;
    onCaseTypeChange(caseType: report): void;
    saveSupportingDocument(event: any): void;
    onCategoryChange(event: any): void;
    onPriorityChange(event: any): void;
    onRcChange(event: any): void;
    onCaseTypeDropdownChange(event: any): void;
    reportCase(): void;
    updateCase(): void;
    checkValidation(payload: any): boolean;
    checkAddToCaseValidation(payload: any): boolean;
    validateName(name: string): boolean;
    validateDescription(description: string): boolean;
    validateCaseType(caseType: string): boolean;
    validateReportDate(reportDate: string): boolean;
    validateCasePriority(priority: string): boolean;
    validateRc(payload: any): boolean;
    validateCaseOwner(owners: any): boolean;
    validateCaseAssignee(assignees: any): boolean;
    validateCaseAssigneeGroup(assignees_group: any): boolean;
    validateCaseResolutionDeadline(resolutionDeadline: any): boolean;
    onFieldClicked(event: any): void;
    addMoreInfo(event: any): void;
    setActiveFieldSelector(field: string, type: string): void;
    fieldDeselector(type: any): void;
    pickerToggle(type: boolean): void;
    setException(type: any): void;
    checkDescription(): void;
    selectFile(type: string, files: any): void;
    uploadFile(file: any, type: string): void;
    setEvidence(value: any): void;
    deleteItem(type: any, element: any): void;
    selectorAction(evt: any, type: any): void;
    getCcUsers(evt: any, type: string): void;
    filterOversights(): void;
    filterResponsibilities(payload: any): void;
    filterAssessment(payload: any): void;
    formatDueDate(date: any): string;
    updateDate(): void;
    addToCase(): void;
    addCaseToWorkflow(): void;
    updateAddToCase(): void;
    smileyActions(evt: any): void;
    viewCase(): void;
    resetForm(): void;
    reportACaseReset(): void;
    addToCaseReset(): void;
    closeSmiley(evt?: any): void;
    closeWorkFlow(evt: any, confirm: any): void;
    onCaseLoader(event: any, type: string): void;
    get displayAdditionalOptions(): any;
    get checkloader(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<WorkflowCaseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WorkflowCaseComponent, "app-workflow-case", never, { "openedFrom": { "alias": "openedFrom"; "required": false; }; "source": { "alias": "source"; "required": false; }; "caseId": { "alias": "caseId"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "workflowType": { "alias": "workflowType"; "required": false; }; "responsibilityData": { "alias": "responsibilityData"; "required": false; }; "assessmentQuestion": { "alias": "assessmentQuestion"; "required": false; }; "caseTypePermission": { "alias": "caseTypePermission"; "required": false; }; }, { "closeWorkflow": "closeWorkflow"; "populateOption": "populateOption"; "caseReportedBy": "caseReportedBy"; "userListEmitter": "userListEmitter"; "disconnectRefresh": "disconnectRefresh"; "pickerChanged": "pickerChanged"; }, never, never, false, never>;
}
