import { PipeTransform } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * @Pipe SearchByKeys
 *
 * A custom Angular pipe that filters an array of objects based on a search value and specified keys.
 *
 * @example
 * <div *ngFor="let item of items | SearchByKeys: ['name', 'description']: searchValue">
 *   {{ item.name }}
 * </div>
 *
 * @class
 * @implements {PipeTransform}
 */
/**
 * Transforms an array of objects by filtering them based on the provided keys and search value.
 *
 * @param {any[]} items - The array of objects to be filtered.
 * @param {string[]} keys - The keys of the objects to be searched.
 * @param {string} value - The search value to filter the objects.
 * @returns {any[]} - The filtered array of objects.
 */
/**
 * Searches within an object for a value.
 *
 * @private
 * @param {any} obj - The object to search within.
 * @param {string} value - The search value.
 * @returns {boolean} - True if the value is found within the object, otherwise false.
 */
export declare class SearchByKeysPipe implements PipeTransform {
    transform(items: any[], keys: string[], value: string): any[];
    private searchInObject;
    static ɵfac: i0.ɵɵFactoryDeclaration<SearchByKeysPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<SearchByKeysPipe, "SearchByKeys", false>;
}
